@@ -13,6 +13,7 @@ from deepforest import dataset
 from deepforest import get_data
 from deepforest import model
 from deepforest import predict
+from deepforest import visualize
 from deepforest import evaluate as evaluate_iou
 from pytorch_lightning.callbacks import LearningRateMonitor
 
@@ -29,6 +30,12 @@ class deepforest(pl.LightningModule):
         """
         super().__init__()
         
+        #Pytorch lightning handles the device, but we need one for adhoc methods like predict_image.
+        if torch.cuda.is_available():
+            self.current_device = torch.device("cuda")
+        else:
+            self.current_device = torch.device("cpu")
+            
         # Read config file - if a config file exists in local dir use it,
         # if not use installed.
         if os.path.exists("deepforest_config.yml"):
@@ -52,7 +59,9 @@ class deepforest(pl.LightningModule):
         
         #Label encoder and decoder
         if not len(label_dict) == num_classes:
-            raise ValueError("label_dict {} does not match requested number of classes {}, please supply a label_dict argument {'label1':0, 'label2':1, 'label3':2 ... etc} for each label in the dataset".format(label_dict, num_classes))
+            raise ValueError(
+                'label_dict {} does not match requested number of classes {}, please supply a label_dict argument {{"label1":0, "label2":1, "label3":2 ... etc}} for each label in the dataset'.format(label_dict, num_classes)
+            )
         
         self.label_dict = label_dict
         self.numeric_to_label_dict = {v: k for k, v in label_dict.items()}
@@ -192,8 +201,8 @@ class deepforest(pl.LightningModule):
             image = io.imread(path)
 
             # Load on GPU is available
-        if torch.cuda.is_available:
-            self.model.to(self.device)
+        if torch.cuda.is_available():
+            self.model.to("cuda")
 
         self.model.eval()
 
@@ -201,7 +210,7 @@ class deepforest(pl.LightningModule):
         result = predict.predict_image(model=self.model,
                                        image=image,
                                        return_plot=return_plot,
-                                       device=self.device,
+                                       device=self.current_device,
                                        iou_threshold=self.config["nms_thresh"])
         
         #Set labels to character from numeric if returning boxes df
@@ -229,7 +238,7 @@ class deepforest(pl.LightningModule):
                                       csv_file=csv_file,
                                       root_dir=root_dir,
                                       savedir=savedir,
-                                      device=self.device,
+                                      device=self.current_device,
                                       iou_threshold=self.config["nms_thresh"])
 
         #Set labels to character from numeric
@@ -282,7 +291,7 @@ class deepforest(pl.LightningModule):
                                       use_soft_nms=use_soft_nms,
                                       sigma=sigma,
                                       thresh=thresh,
-                                      device=self.device)
+                                      device=self.current_device)
 
         #edge case, if no boxes predictioned return None
         if result is None:
@@ -365,19 +374,29 @@ class deepforest(pl.LightningModule):
         """
         self.model.eval()
 
-        if not self.device.type == "cpu":
-            self.model = self.model.to(self.device)
+        if torch.cuda.is_available():
+            self.model.to("cuda")
 
         predictions = predict.predict_file(model=self.model,
                                            csv_file=csv_file,
                                            root_dir=root_dir,
                                            savedir=savedir,
-                                           device=self.device,
+                                           device=self.current_device,
                                            iou_threshold=self.config["nms_thresh"])
         
-        predictions["label"] = predictions.label.apply(lambda x: self.numeric_to_label_dict[x])
         ground_df = pd.read_csv(csv_file)
-
+        
+        if savedir:
+            for image_path, group in predictions.groupby("image_path"):
+                plot_ground_truth = ground_df[ground_df["image_path"] == image_path].reset_index(drop=True)
+                group = group.reset_index(drop=True)
+                visualize.plot_prediction_dataframe(df=predictions,
+                                                    ground_truth=plot_ground_truth,
+                                                    root_dir=root_dir,
+                                                    savedir=savedir)
+            
+        predictions["label"] = predictions["label"].apply(lambda x: self.numeric_to_label_dict[x])
+        
         # if no arg for iou_threshold, set as config
         if iou_threshold is None:
             iou_threshold = self.config["validation"]["iou_threshold"]
@@ -385,7 +404,6 @@ class deepforest(pl.LightningModule):
         results = evaluate_iou.evaluate(predictions=predictions,
                                         ground_df=ground_df,
                                         root_dir=root_dir,
-                                        iou_threshold=iou_threshold,
-                                        show_plot=show_plot)
+                                        iou_threshold=iou_threshold)
 
         return results
